version

package
v0.3.29-beta Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 8, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package version provides version information for kodelet including semantic version, git commit SHA, build time, and build information that are set during the build process.

Index

Constants

This section is empty.

Variables

var (
	// Version is the current version of Kodelet
	// This will be set during the build process from VERSION.txt
	Version = "dev"

	// GitCommit is the git commit SHA that was built
	// This will be set during the build process
	GitCommit = "unknown"

	// BuildTime is the time when the binary was built
	// This will be set during the build process
	BuildTime = "unknown"
)

Functions

This section is empty.

Types

type Info

type Info struct {
	Version   string `json:"version"`
	GitCommit string `json:"gitCommit"`
	BuildTime string `json:"buildTime"`
	GoVersion string `json:"goVersion"`
}

Info represents version information

func Get

func Get() Info

Get returns the version information

func (Info) JSON

func (i Info) JSON() (string, error)

JSON returns the JSON representation of version info

func (Info) String

func (i Info) String() string

String returns the string representation of version info

Jump to